restored missing tumbleweed
[naja.git] / setup.py
index e8042f9e8b1d5ae967bed2da00bbeda10a72a98c..f39ff02542efe5d89ebfbb3b2f7eccc7c9a0940e 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -2,9 +2,13 @@
 # -*- coding: utf8 -*-
 # vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
 
"""Setuptools setup.py file for naja."""
 
 from setuptools import setup, find_packages
+from setuptools.command.sdist import sdist
+from setuptools.command.install import install
+
+from tools import gen_json
 
 try:
     import py2exe
@@ -15,10 +19,23 @@ except ImportError:
 # This should probably be pulled from constants.py
 VERSION_STR = "0.1"
 
+
+class NajaSdist(sdist):
+    def run(self):
+        gen_json.main()
+        sdist.run(self)
+
+
+class NajaInstall(install):
+    def run(self):
+        gen_json.main(update=False)
+        install.run(self)
+
+
 setup(
-    name="naja",
+    name="robolock-II",
     version=VERSION_STR,
-    description="naja: Game for PyWeek 18",
+    description="Robolock II - a puzzle game",
 
     author=(", ".join([
         "Simon Cross",
@@ -30,10 +47,10 @@ setup(
     ])),
     author_email="ctpug@googlegroups.com",
 
-    maintainer="Naja Team",
+    maintainer="Team Naja (CTPUG)",
     maintainer_email="ctpug@googlegroups.com",
 
-    url="http://ctpug.org.za/",
+    url="http://robolock.org/",
     download_url="http://ctpug.org.za/git/naja",
 
     license="MIT",
@@ -63,6 +80,9 @@ setup(
     # Dependencies
     install_requires=[
         'pygame',
+    ],
+
+    setup_requires=[
         'PyYAML',
     ],
 
@@ -72,6 +92,11 @@ setup(
         'scripts/naja',
     ],
 
+    cmdclass={
+        'sdist': NajaSdist,
+        'install': NajaInstall,
+    },
+
     # py2exe
     windows=[{
         'script': 'scripts/naja',
@@ -2,9 +2,13 @@
 # vim:fileencoding=utf8 ai ts=4 sts=4 et sw=4
 
-"""Setuptools setup.py file for naja."""
+"""Setuptools setup.py file for Robolock II."""
 
 from setuptools import setup, find_packages